import { parse, parseFragment, serialize } from 'nodemod/dist/lib/parse5.js';

async function processLiterals(strings, ...exps) {
    const listTask = exps.map(async (n) => {
        const tasks = (Array.isArray(n) ? n : [n])
            .map(async (o) => 'function' === typeof (o) ? o() : o);
        return Promise.all(tasks);
    });
    const done = await Promise.all(listTask);
    const doneLen = done.length;
    return strings.reduce((p, n, i) => {
        const nTask = done[i];
        const joined = Array.isArray(nTask) ? nTask.join('') : nTask;
        return `${p}${i >= doneLen ? n : `${n}${joined}`}`;
    }, '');
}

function parsePartial(serializeFn) {
    return async (fn, strings, ...exps) => {
        const content = await processLiterals(strings, ...exps);
        return serializeFn(fn(content));
    };
}

const parser = parsePartial(serialize);
const html = async (s, ...e) => parser(c => parse(`<!doctype html>${c}`), s, ...e);
const htmlFragment = async (s, ...e) => parser(parseFragment, s, ...e);
var litNtml = { html, htmlFragment };

export default litNtml;
export { html, htmlFragment };
//# sourceMappingURL=lit-ntml.js.map
